@@ -15,7 +15,7 @@ def handler(obj):
     return dictionary
 
 
-class Builder(object):
+class Builder:
     """ Builder of GPAO's json project """
 
     def __init__(self, projects=None):
@@ -37,7 +37,7 @@ class Builder(object):
         for project in self.projects:
             Project.reorganize_job_dependencies(project)
             json_gpao["projects"].append(project)
-        with open(file_json, "w") as fjson:
+        with open(file_json, "w", encoding="utf-8") as fjson:
             json.dump(
                 json_gpao,
                 fjson,
